@@ -17,7 +17,7 @@ Usage::
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_datapipeline.type_defs import (
     DescribeObjectsOutputTypeDef,
@@ -33,7 +33,7 @@ __all__ = ("DescribeObjectsPaginator", "ListPipelinesPaginator", "QueryObjectsPa
 
 class DescribeObjectsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+    [Paginator.DescribeObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
     """
 
     def paginate(
@@ -42,28 +42,28 @@ class DescribeObjectsPaginator(Boto3Paginator):
         objectIds: List[str],
         evaluateExpressions: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeObjectsOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeObjectsOutputTypeDef]:
         """
-        [DescribeObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
+        [DescribeObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPipelinesOutputTypeDef, None, None]:
+    ) -> Iterator[ListPipelinesOutputTypeDef]:
         """
-        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
+        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
         """
 
 
 class QueryObjectsPaginator(Boto3Paginator):
     """
-    [Paginator.QueryObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+    [Paginator.QueryObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
     """
 
     def paginate(
@@ -72,7 +72,7 @@ class QueryObjectsPaginator(Boto3Paginator):
         sphere: str,
         query: QueryTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[QueryObjectsOutputTypeDef, None, None]:
+    ) -> Iterator[QueryObjectsOutputTypeDef]:
         """
-        [QueryObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
+        [QueryObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
         """
